@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::Glacier::ListJobs;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.100';
 
 use strict;
 use warnings;
@@ -30,7 +30,6 @@ use Carp;
 use JSON::XS 1.00;
 
 use App::MtAws::Utils;
-use App::MtAws::MetaData;
 
 
 sub new
@@ -46,7 +45,7 @@ sub _parse
 	my ($self) = @_;
 	return if $self->{data};
 	$self->{data} = JSON::XS->new->allow_nonref->decode(${ delete $self->{rawdata} || confess });
-
+	
 	# get rid of JSON::XS boolean object, just in case.
 	# also JSON::XS between versions 1.0 and 2.1 (inclusive) do not allow to modify this field
 	# (modification of read only error thrown)
@@ -59,26 +58,6 @@ sub _completed
 	$_->{Completed} && $_->{StatusCode} eq 'Succeeded'
 }
 
-sub _full_inventory
-{
-	!(
-		$_->{InventoryRetrievalParameters} &&
-		(
-			defined $_->{InventoryRetrievalParameters}{StartDate} ||
-			defined $_->{InventoryRetrievalParameters}{EndDate} ||
-			defined $_->{InventoryRetrievalParameters}{Limit} ||
-			defined $_->{InventoryRetrievalParameters}{Marker}
-		)
-	)
-}
-
-# TODO: yet unused. release after some time
-sub _meta_full_inventory
-{
-	my ($type) = meta_job_decode($_->{JobDescription});
-	$type && $type eq META_JOB_TYPE_FULL;
-}
-
 sub _filter_and_return_entries
 {
 	my ($self, $filter_cb) = @_;
@@ -89,12 +68,13 @@ sub _filter_and_return_entries
 
 sub get_inventory_entries
 {
-	shift->_filter_and_return_entries(sub { $_->{Action} eq 'InventoryRetrieval' && _completed() && _full_inventory() }); #  && _meta_full_inventory()
+	shift->_filter_and_return_entries(sub { _completed() && $_->{Action} eq 'InventoryRetrieval' });
 }
 
 sub get_archive_entries
 {
-	shift->_filter_and_return_entries(sub { $_->{Action} eq 'ArchiveRetrieval' && _completed() });
+	shift->_filter_and_return_entries(sub { _completed() && $_->{Action} eq 'ArchiveRetrieval' });
 }
 
 1;
+
