@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::QueueJob::DownloadInventory;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.100';
 
 use strict;
 use warnings;
@@ -42,7 +42,6 @@ sub on_download
 	return state "wait", task "inventory_download_job", { job_id => $self->{job_id} } => sub {
 		my ($args, $attachment) = @_;
 		$self->{inventory_raw_ref} = $attachment || confess "no attachment"; # we don't expect undef/FALSE here. only scalar ref
-		$self->{inventory_type} = $args->{inventory_type} || confess "no inventory type";
 		state("done")
 	}
 }
