@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::QueueJob::MultipartPart;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.100';
 
 use strict;
 use warnings;
@@ -40,7 +40,6 @@ sub init
 	defined($self->{mtime})||confess;
 	$self->{upload_id}||confess;
 	$self->{fh}||confess;
-	exists($self->{stdin})||confess;
 	$self->{all_raised} = 0;
 	$self->{position} = 0;
 	$self->{th} = App::MtAws::TreeHash->new();
@@ -49,13 +48,6 @@ sub init
 	$self->enter('fist_part');
 }
 
-
-sub close_file
-{
-	my ($self) = @_;
-	close($self->{fh}) or confess;
-}
-
 sub read_part
 {
 	my ($self) = @_;
@@ -73,7 +65,7 @@ sub read_part
 
 		return (1, $start, $part_final_hash, $attachment);
 	} else {
-		die exception 'cannot_read_from_file' => "Cannot read from file errno=%errno%", 'ERRNO'  unless defined $r;
+		confess "IO error $!" unless defined $r;
 		return;
 	}
 
@@ -115,14 +107,8 @@ sub on_other_parts
 {
 	my ($self) = @_;
 	my @res = $self->get_part();
-	return @res ? @res : (keys %{$self->{uploadparts}} ? JOB_WAIT : state('close'));
+	return @res ? @res : (keys %{$self->{uploadparts}} ? JOB_WAIT : state('done'));
 }
 
-sub on_close
-{
-	my ($self) = @_;
-	$self->{stdin} or $self->close_file; # close file after EOF found
-	state("done");
-}
 
 1;
