@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::QueueJob::RetrieveInventory;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.100';
 
 use strict;
 use warnings;
@@ -32,15 +32,13 @@ use base 'App::MtAws::QueueJob';
 sub init
 {
 	my ($self) = @_;
-	$self->{format} or confess;
-	$self->{format} =~ /^json|csv$/ or confess;
 	$self->enter('retrieve');
 }
 
 sub on_retrieve
 {
 	my ($self) = @_;
-	return state "wait", task "retrieve_inventory_job", { format => $self->{format} } => sub {
+	return state "wait", task "retrieve_inventory_job", { } => sub {
 		state("done")
 	}
 }
