@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::QueueJob::UploadMultipart;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.100';
 
 use strict;
 use warnings;
@@ -61,7 +61,7 @@ sub on_part
 	my ($self) = @_;
 	return
 		state("wait"),
-		job( App::MtAws::QueueJob::MultipartPart->new(map { $_ => $self->{$_} } qw/relfilename stdin partsize mtime upload_id fh/), sub {
+		job( App::MtAws::QueueJob::MultipartPart->new(map { $_ => $self->{$_} } qw/relfilename partsize mtime upload_id fh/), sub {
 			my $j = shift;
 			$self->{filesize} = $j->{position} || confess;
 			$self->{th} = $j->{th} || confess;
