@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,14 +20,14 @@
 
 package App::MtAws::QueueJobResult;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.100';
 
 use strict;
 use warnings;
 
 use Carp;
 use Scalar::Util qw/blessed/;
-use Exporter 'import';
+use base 'Exporter';
 
 use constant JOB_RETRY => "MT_J_RETRY";
 use constant JOB_OK => "MT_J_OK";
